@@ -1,11 +1,11 @@
 from typing import List
 
-from ts_t1_validator.models.enums.location_type import LocationTypeEnum
+from ts_t1_validator.models.enums.targeting_type import TargetingTypeEnum
 
 
 class TargetingLocationDTO:
-    def __init__(self, location_type: LocationTypeEnum, included: List[int], excluded: List[int]):
-        self.location_type = location_type
+    def __init__(self, targeting_type: TargetingTypeEnum, included: List[int], excluded: List[int]):
+        self.targeting_type = targeting_type
         self.included = included
         self.excluded = excluded
 
@@ -16,6 +16,6 @@ class TargetingLocationDTO:
         :param user_data: dict
         :return:
         """
-        return TargetingLocationDTO(location_type=LocationTypeEnum.set(user_data.get("location_type")),
+        return TargetingLocationDTO(targeting_type=TargetingTypeEnum.set(user_data.get("targeting_type")),
                                     included=user_data.get("included"),
                                     excluded=user_data.get("excluded"))
