@@ -5,6 +5,6 @@ from ts_t1_validator.models.enums.abstract_enum import AbstractEnum
 
 @unique
 class TargetingTypeEnum(AbstractEnum):
-    INCLUDE = "include"
-    EXCLUDE = "exclude"
+    DMAX = "DMAX"
+    REGION = "REGN"
     UNDEFINED = None
