@@ -4,7 +4,7 @@ from ts_t1_validator.models.enums.cap_type import CapTypeEnum
 
 
 class CapAutomaticRule(ValidationRule):
-    def __init__(self, cap_type, cap_automatic, cap_fields={}):
+    def __init__(self, cap_type, cap_automatic, cap_fields=dict):
         assert isinstance(cap_type, CapTypeEnum)
 
         self.cap_type = cap_type
