@@ -1,13 +1,10 @@
 from ts_t1_validator import AbstractValidator, T1Service
 from ts_t1_validator.models.dto.targeting_location import TargetingLocationDTO
-from ts_t1_validator.models.enums.location_type import LocationTypeEnum
 from ts_t1_validator.models.enums.targeting_type import TargetingTypeEnum
 
 from ts_t1_validator.validators.rules.one_of_enum_rule import OneOfEnumRule
 from ts_t1_validator.validators.rules.positive_id_list_rule import PositiveIDListRule
-from ts_t1_validator.validators.rules.positive_id_rule import PositiveIDRule
 from ts_t1_validator.validators.rules.t1_ids_same_check import T1CheckIds
-from ts_t1_validator.validators.rules.targeting_location_in_list_rule import TargetingLocationInList
 from ts_t1_validator.validators.rules.targeting_locations_in_list_rule import TargetingLocationsInList
 
 
@@ -34,15 +31,15 @@ class TargetingLocationValidator(AbstractValidator):
 
         self.rules.append(PositiveIDListRule(values=dto.included, field_name="Included"))
         self.rules.append(PositiveIDListRule(values=dto.excluded, field_name="Excluded"))
-        self.rules.append(OneOfEnumRule(value=dto.location_type, expected_enum=LocationTypeEnum,
-                                        field_name="Location Type"))
+        self.rules.append(OneOfEnumRule(value=dto.targeting_type, expected_enum=TargetingTypeEnum,
+                                        field_name="Targeting Type"))
 
         self.rules.append(T1CheckIds(include_value_ids=dto.included, exclude_value_ids=dto.excluded,
-                                     location_type=dto.location_type))
+                                     targeting_type=dto.targeting_type))
         self.rules.append(TargetingLocationsInList(values=dto.included,
-                                                   location_type=dto.location_type,
+                                                   targeting_type=dto.targeting_type,
                                                    field_name="Included"))
 
         self.rules.append(TargetingLocationsInList(values=dto.excluded,
-                                                   location_type=dto.location_type,
+                                                   targeting_type=dto.targeting_type,
                                                    field_name="Excluded"))
